pecos.slr.gen\_codes.gen\_qasm
==============================

.. automodule:: pecos.slr.gen_codes.gen_qasm







   .. rubric:: Functions

   .. autosummary::

      process_permute





   .. rubric:: Classes

   .. autosummary::

      QASMGenerator
